aboutsummaryrefslogtreecommitdiffstats
path: root/Frameworks/PostgresKit/Source
diff options
context:
space:
mode:
authorstuconnolly <stuart02@gmail.com>2012-09-09 00:51:43 +0000
committerstuconnolly <stuart02@gmail.com>2012-09-09 00:51:43 +0000
commit44ca403e94e748cbf1db6941aece22029c77c542 (patch)
tree6f6273a8ea5a335af89c34edc49012330d5ccd5e /Frameworks/PostgresKit/Source
parente7a80d32707951967ba59c89e3f91d43573995b4 (diff)
downloadsequelpro-44ca403e94e748cbf1db6941aece22029c77c542.tar.gz
sequelpro-44ca403e94e748cbf1db6941aece22029c77c542.tar.bz2
sequelpro-44ca403e94e748cbf1db6941aece22029c77c542.zip
Rename some classes.
Diffstat (limited to 'Frameworks/PostgresKit/Source')
-rw-r--r--Frameworks/PostgresKit/Source/FLXPostgresKitPrivateAPI.h4
-rw-r--r--Frameworks/PostgresKit/Source/FLXPostgresTimeInterval.h (renamed from Frameworks/PostgresKit/Source/FLXTimeInterval.h)6
-rw-r--r--Frameworks/PostgresKit/Source/FLXPostgresTimeInterval.m (renamed from Frameworks/PostgresKit/Source/FLXTimeInterval.m)6
-rw-r--r--Frameworks/PostgresKit/Source/FLXPostgresTimeTZ.h (renamed from Frameworks/PostgresKit/Source/FLXTimeTZ.h)8
-rw-r--r--Frameworks/PostgresKit/Source/FLXPostgresTimeTZ.m (renamed from Frameworks/PostgresKit/Source/FLXTimeTZ.m)12
-rw-r--r--Frameworks/PostgresKit/Source/FLXPostgresTypeDateTimeHandler.m8
-rw-r--r--Frameworks/PostgresKit/Source/FLXPostgresTypes.h6
7 files changed, 25 insertions, 25 deletions
diff --git a/Frameworks/PostgresKit/Source/FLXPostgresKitPrivateAPI.h b/Frameworks/PostgresKit/Source/FLXPostgresKitPrivateAPI.h
index 174b8018..d78ac063 100644
--- a/Frameworks/PostgresKit/Source/FLXPostgresKitPrivateAPI.h
+++ b/Frameworks/PostgresKit/Source/FLXPostgresKitPrivateAPI.h
@@ -21,7 +21,7 @@
// the License.
#import "FLXPostgresConnection.h"
-#import "FLXTimeInterval.h"
+#import "FLXPostgresTimeInterval.h"
@interface FLXPostgresConnection ()
@@ -35,7 +35,7 @@
@end
-@interface FLXTimeInterval ()
+@interface FLXPostgresTimeInterval ()
- (id)initWithInterval:(const PGinterval *)interval;
diff --git a/Frameworks/PostgresKit/Source/FLXTimeInterval.h b/Frameworks/PostgresKit/Source/FLXPostgresTimeInterval.h
index 09fe4bf9..74f14c41 100644
--- a/Frameworks/PostgresKit/Source/FLXTimeInterval.h
+++ b/Frameworks/PostgresKit/Source/FLXPostgresTimeInterval.h
@@ -1,7 +1,7 @@
//
// $Id$
//
-// FLXTimeInterval.h
+// FLXPostgresTimeInterval.h
// PostgresKit
//
// Created by Stuart Connolly (stuconnolly.com) on September 9, 2012.
@@ -29,13 +29,13 @@
// OTHER DEALINGS IN THE SOFTWARE.
/**
- * @class FLXTimeInterval FLXTimeInterval.h
+ * @class FLXPostgresTimeInterval FLXPostgresTimeInterval.h
*
* @author Stuart Connolly http://stuconnolly.com
*
* Simple wrapper around libpqtypes' PQinterval structure.
*/
-@interface FLXTimeInterval : NSObject
+@interface FLXPostgresTimeInterval : NSObject
{
NSUInteger _microseconds;
NSUInteger _seconds;
diff --git a/Frameworks/PostgresKit/Source/FLXTimeInterval.m b/Frameworks/PostgresKit/Source/FLXPostgresTimeInterval.m
index 48f8cbd4..7faaad41 100644
--- a/Frameworks/PostgresKit/Source/FLXTimeInterval.m
+++ b/Frameworks/PostgresKit/Source/FLXPostgresTimeInterval.m
@@ -1,7 +1,7 @@
//
// $Id$
//
-// FLXTimeInterval.m
+// FLXPostgresTimeInterval.m
// PostgresKit
//
// Created by Stuart Connolly (stuconnolly.com) on September 9, 2012.
@@ -28,10 +28,10 @@
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
-#import "FLXTimeInterval.h"
+#import "FLXPostgresTimeInterval.h"
#import "FLXPostgresKitPrivateAPI.h"
-@implementation FLXTimeInterval
+@implementation FLXPostgresTimeInterval
@synthesize microseconds = _microseconds;
@synthesize seconds = _seconds;
diff --git a/Frameworks/PostgresKit/Source/FLXTimeTZ.h b/Frameworks/PostgresKit/Source/FLXPostgresTimeTZ.h
index a24fc2cf..dd58f57f 100644
--- a/Frameworks/PostgresKit/Source/FLXTimeTZ.h
+++ b/Frameworks/PostgresKit/Source/FLXPostgresTimeTZ.h
@@ -1,7 +1,7 @@
//
// $Id$
//
-// FLXTimeTZ.h
+// FLXPostgresTimeTZ.h
// PostgresKit
//
// Created by Stuart Connolly (stuconnolly.com) on September 8, 2012.
@@ -29,13 +29,13 @@
// OTHER DEALINGS IN THE SOFTWARE.
/**
- * @class FLXTimeTZ FLXTimeTZ.h
+ * @class FLXPostgresTimeTZ FLXPostgresTimeTZ.h
*
* @author Stuart Connolly http://stuconnolly.com
*
* Simple wrapper to represet a time or timestamp with an associated time zone.
*/
-@interface FLXTimeTZ : NSObject
+@interface FLXPostgresTimeTZ : NSObject
{
BOOL _hasDate;
@@ -55,7 +55,7 @@
*/
@property (readonly) NSTimeZone *timeZone;
-+ (FLXTimeTZ *)timeWithDate:(NSDate *)date timeZoneGMTOffset:(NSUInteger)offset;
++ (FLXPostgresTimeTZ *)timeWithDate:(NSDate *)date timeZoneGMTOffset:(NSUInteger)offset;
- (id)initWithDate:(NSDate *)date timeZoneGMTOffset:(NSUInteger)offset;
diff --git a/Frameworks/PostgresKit/Source/FLXPostgresTypeDateTimeHandler.m b/Frameworks/PostgresKit/Source/FLXPostgresTypeDateTimeHandler.m
index c60c1eb9..b28868cc 100644
--- a/Frameworks/PostgresKit/Source/FLXPostgresTypeDateTimeHandler.m
+++ b/Frameworks/PostgresKit/Source/FLXPostgresTypeDateTimeHandler.m
@@ -25,7 +25,7 @@
#import "FLXPostgresConnectionParameters.h"
#import "FLXPostgresConnection.h"
#import "FLXPostgresConnectionTypeHandling.h"
-#import "FLXTimeTZ.h"
+#import "FLXPostgresTimeTZ.h"
static FLXPostgresOid FLXPostgresTypeDateTimeTypes[] =
{
@@ -148,7 +148,7 @@ static FLXPostgresOid FLXPostgresTypeDateTimeTypes[] =
NSDate *date = [self _dateFromComponents:components];
- return hasTimeZone ? [FLXTimeTZ timeWithDate:date timeZoneGMTOffset:time.gmtoff] : date;
+ return hasTimeZone ? [FLXPostgresTimeTZ timeWithDate:date timeZoneGMTOffset:time.gmtoff] : date;
}
/**
@@ -169,11 +169,11 @@ static FLXPostgresOid FLXPostgresTypeDateTimeTypes[] =
PQgetf(result, row, hasTimeZone ? "%timstamptz" : "%timestamp", column, &timestamp);
- FLXTimeTZ *timestampTZ = nil;
+ FLXPostgresTimeTZ *timestampTZ = nil;
NSDate *date = [NSDate dateWithTimeIntervalSince1970:timestamp.epoch];
if (hasTimeZone) {
- timestampTZ = [FLXTimeTZ timeWithDate:date timeZoneGMTOffset:timestamp.time.gmtoff];
+ timestampTZ = [FLXPostgresTimeTZ timeWithDate:date timeZoneGMTOffset:timestamp.time.gmtoff];
[timestampTZ setHasDate:YES];
}
diff --git a/Frameworks/PostgresKit/Source/FLXPostgresTypes.h b/Frameworks/PostgresKit/Source/FLXPostgresTypes.h
index 0f57daae..3216ad98 100644
--- a/Frameworks/PostgresKit/Source/FLXPostgresTypes.h
+++ b/Frameworks/PostgresKit/Source/FLXPostgresTypes.h
@@ -101,9 +101,9 @@ enum
FLXPostgresOidDate = 1082, // DateHandler => NSDate
FLXPostgresOidTime = 1083, // DateHandler => NSDate
FLXPostgresOidTimestamp = 1114, // DateHandler => NSDate
- FLXPostgresOidTimestampTZ = 1184, // DateHandler => FLXTimeTZ
- FLXPostgresOidInterval = 1186, // DateHandler => FLXTimeInterval
- FLXPostgresOidTimeTZ = 1266, // DateHandler => FLXTimeTZ
+ FLXPostgresOidTimestampTZ = 1184, // DateHandler => FLXPostgresTimeTZ
+ FLXPostgresOidInterval = 1186, // DateHandler => FLXPostgresTimeInterval
+ FLXPostgresOidTimeTZ = 1266, // DateHandler => FLXPostgresTimeTZ
// Binary
FLXPostgresOidBit = 1560, // Currently not supported
diff --git a/Frameworks/PostgresKit/Source/FLXTimeTZ.m b/Frameworks/PostgresKit/Source/FLXPostgresTimeTZ.m
index 48c97aa9..692ef200 100644
--- a/Frameworks/PostgresKit/Source/FLXTimeTZ.m
+++ b/Frameworks/PostgresKit/Source/FLXPostgresTimeTZ.m
@@ -1,7 +1,7 @@
//
// $Id$
//
-// FLXTimeTZ.m
+// FLXPostgresTimeTZ.m
// PostgresKit
//
// Created by Stuart Connolly (stuconnolly.com) on September 8, 2012.
@@ -28,9 +28,9 @@
// FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
// OTHER DEALINGS IN THE SOFTWARE.
-#import "FLXTimeTZ.h"
+#import "FLXPostgresTimeTZ.h"
-@implementation FLXTimeTZ
+@implementation FLXPostgresTimeTZ
@synthesize hasDate = _hasDate;
@synthesize date = _date;
@@ -41,13 +41,13 @@
return [self initWithDate:[NSDate date] timeZoneGMTOffset:[[NSTimeZone systemTimeZone] secondsFromGMT]];
}
-+ (FLXTimeTZ *)timeWithDate:(NSDate *)date timeZoneGMTOffset:(NSUInteger)offset
++ (FLXPostgresTimeTZ *)timeWithDate:(NSDate *)date timeZoneGMTOffset:(NSUInteger)offset
{
- return [[[FLXTimeTZ alloc] initWithDate:date timeZoneGMTOffset:offset] autorelease];
+ return [[[FLXPostgresTimeTZ alloc] initWithDate:date timeZoneGMTOffset:offset] autorelease];
}
/**
* Initialise a FLXTimeTZ with the supplied date and GMT offset.
*
* @param date The date to use.
* @param offset The GMT offset in seconds that the associated time zone is.
@@ -41,13 +41,13 @@
}
/**
- * Initialise a FLXTimeTZ with the supplied date and GMT offset.
+ * Initialise a FLXPostgresTimeTZ with the supplied date and GMT offset.
*
* @param date The date to use.